# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class PatientMerge(EventTypeAbstractModel):

    Meta: "PatientMergeMeta" = Field(...)
    Patient: "PatientMergePatient" = Field(...)


class PatientMergeMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["PatientMergeMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["PatientMergeMetaLog"] = Field(None)
    Message: "PatientMergeMetaMessage" = Field(None)
    Source: "PatientMergeMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "PatientMergeMetaTransmission" = Field(None)


class PatientMergeMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientMergeMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class PatientMergeMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PatientMergeMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PatientMergeMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PatientMergePatient(RedoxAbstractModel):

    Demographics: "PatientMergePatientDemographics" = Field(None)
    Identifiers: List["PatientMergePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)
    PreviousIdentifiers: List["PatientMergePatientPreviousIdentifier"] = Field(...)


class PatientMergePatientDemographics(RedoxAbstractModel):

    Address: "PatientMergePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "PatientMergePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PatientMergePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PatientMergePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class PatientMergePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class PatientMergePatientPreviousIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


PatientMerge.update_forward_refs()
PatientMergeMeta.update_forward_refs()
PatientMergePatient.update_forward_refs()
PatientMergePatientDemographics.update_forward_refs()



# -*- coding: utf-8 -*-
# flake8: noqa: F401
from .availableslots import AvailableSlots
from .availableslotsresponse import AvailableSlotsResponse
from .booked import Booked
from .bookedresponse import BookedResponse
from .cancel import Cancel
from .modification import Modification
from .new import New
from .noshow import NoShow
from .pushslots import PushSlots
from .reschedule import Reschedule



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyredox',
 'pyredox.claim',
 'pyredox.clinicaldecisions',
 'pyredox.clinicalsummary',
 'pyredox.device',
 'pyredox.financial',
 'pyredox.flowsheet',
 'pyredox.generic',
 'pyredox.inventory',
 'pyredox.media',
 'pyredox.medications',
 'pyredox.notes',
 'pyredox.order',
 'pyredox.organization',
 'pyredox.patientadmin',
 'pyredox.patienteducation',
 'pyredox.patientsearch',
 'pyredox.provider',
 'pyredox.referral',
 'pyredox.research',
 'pyredox.results',
 'pyredox.scheduling',
 'pyredox.sso',
 'pyredox.surgicalscheduling',
 'pyredox.vaccination']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.9.0,<1.10.0']

extras_require = \
{':python_version >= "3.6" and python_version < "3.7"': ['dataclasses>=0.8,<0.9']}

setup_kwargs = {
    'name': 'pyredox',
    'version': '0.1.0a1',
    'description': '',
    'long_description': '# Pyredox - A Pydantic-Based Library for Redox Data\n\n[![PyPI Info](https://img.shields.io/pypi/v/pyredox.svg)](https://pypi.python.org/pypi/pyredox)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/cedar-team/pyredox/main)](https://github.com/cedar-team/pyredox/actions)\n[![Coverage Info](https://coveralls.io/repos/github/cedar-team/pyredox/badge.svg?branch=main)](https://coveralls.io/github/cedar-team/pyredox?branch=main)\n[![Black Code Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\nPyredox is library for producing, ingesting, and validating data from [Redox], a\n"data platform designed to connect providers, payers and products."\n\nPyredox is a set of [Pydantic] models that conforms to the [Redox data model]\nspecification for the purpose of making it easy to convert Redox-formatted JSON to\nPython objects and vice versa. Because pyredox inherits the functionality of\nPydantic, it validates that the JSON data conforms to the spec automatically upon\nobject creation.\n\nFor example, if you tried to create a [`NewPatient`\nmodel](https://developer.redoxengine.com/data-models/PatientAdmin.html#NewPatient) with\ninsufficient data, you would get an error like this:\n\n```python\n>>> from pyredox.patientadmin.newpatient import NewPatient\n>>> NewPatient(Meta={})\n\nValidationError: 3 validation errors for NewPatient\nMeta -> DataModel\n  field required (type=value_error.missing)\nMeta -> EventType\n  field required (type=value_error.missing)\nPatient\n  field required (type=value_error.missing)\n```\n\n\n## Usage\n\nThe simplest way to create a `pyredox` model from a JSON payload is to pass an\nunpacked `dict` as the parameter when initializing the object, like this:\n\n```python\npayload_str = """\n{\n   "Meta": {\n      "DataModel": "PatientAdmin",\n      "EventType": "NewPatient"\n   },\n   "Patient": {\n      "Identifiers": [\n         {\n            "ID": "e167267c-16c9-4fe3-96ae-9cff5703e90a",\n            "IDType": "EHRID"\n         }\n      ]\n   }\n}\n"""\ndata = json.loads(payload_str)\nnew_patient = NewPatient(**data)\n```\n\nIf you have a payload and don\'t know which object type it is, you can use the\nfactory helper, which can take a JSON string or the loaded JSON dict/list:\n\n```python\nfrom pyredox.factory import redox_object_factory\n\nredox_object1 = redox_object_factory(payload_str)  # str input\nredox_object2 = redox_object_factory(data)  # dict input\n```\n\nTo create a JSON payload to send to Redox from an existing `pyredox` object, just\ncall the `json()` method of the object:\n\n```python\nnew_patient.json()\n```\n\nWhen working with the individual fields of a model object, you can traverse the\nelement properties like so:\n\n```python\nnew_patient.patient.identifiers[0].id  # "e167267c-16c9-4fe3-96ae-9cff5703e90a"\n```\n\n\n[Redox]: https://www.redoxengine.com/\n[Redox data model]: https://developer.redoxengine.com/data-models/index.html\n[Pydantic]: https://pydantic-docs.helpmanual.io/\n',
    'author': 'Mike Mabey',
    'author_email': 'mike.mabey@cedar.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/cedar-team/pyredox',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6.1,<4.0',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import clinicalsummary
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _ClinicalSummary(GenericRedoxAbstractModel):
    _redox_module = clinicalsummary


class DocumentGet(_ClinicalSummary):

    Document: generic.Document = Field(...)
    Meta: generic.Meta = Field(...)


class DocumentGetResponse(_ClinicalSummary):

    Data: str = Field(...)
    Document: generic.Document = Field(...)
    FileType: str = Field(...)
    Meta: generic.Meta = Field(...)


class DocumentQuery(_ClinicalSummary):

    Document: generic.Document = Field(None)
    Location: generic.Location = Field(None)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class DocumentQueryResponse(_ClinicalSummary):

    Documents: List[generic.Document] = Field(...)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)


class PatientPush(_ClinicalSummary):

    AdvanceDirectives: List[generic.AdvanceDirective] = Field(None)
    AdvanceDirectivesText: Union[str, None] = Field(None)
    Allergies: List[generic.Allergy] = Field(None)
    AllergyText: Union[str, None] = Field(None)
    Encounters: List[generic.Encounter] = Field(None)
    EncountersText: Union[str, None] = Field(None)
    FamilyHistory: List[generic.FamilyHistory] = Field(None)
    FamilyHistoryText: Union[str, None] = Field(None)
    FunctionalStatus: generic.FunctionalStatus = Field(None)
    FunctionalStatusText: Union[str, None] = Field(None)
    Goals: List[generic.Goal] = Field(None)
    GoalsText: Union[str, None] = Field(None)
    Header: generic.Header = Field(None)
    HealthConcerns: List[generic.HealthConcern] = Field(None)
    HealthConcernsText: Union[str, None] = Field(None)
    Immunizations: List[generic.Immunization] = Field(None)
    ImmunizationText: Union[str, None] = Field(None)
    Insurances: List[generic.Insurance] = Field(None)
    InsurancesText: Union[str, None] = Field(None)
    MedicalEquipment: List[generic.MedicalEquipment] = Field(None)
    MedicalEquipmentText: Union[str, None] = Field(None)
    MedicalHistoryText: Union[str, None] = Field(None)
    Medications: List[generic.Medication] = Field(None)
    MedicationsText: Union[str, None] = Field(None)
    Meta: generic.Meta = Field(...)
    NoteSections: List[generic.NoteSection] = Field(None)
    PlanOfCare: generic.PlanOfCare = Field(None)
    PlanOfCareText: Union[str, None] = Field(None)
    Problems: List[generic.Problem] = Field(None)
    ProblemsText: Union[str, None] = Field(None)
    Procedures: generic.Procedures = Field(None)
    ProceduresText: Union[str, None] = Field(None)
    ResolvedProblems: List[generic.ResolvedProblem] = Field(None)
    ResolvedProblemsText: Union[str, None] = Field(None)
    Results: List[generic.Result] = Field(None)
    ResultText: Union[str, None] = Field(None)
    SocialHistory: generic.SocialHistory = Field(None)
    SocialHistoryText: Union[str, None] = Field(None)
    VitalSigns: List[generic.VitalSign] = Field(None)
    VitalSignsText: Union[str, None] = Field(None)


class PatientQuery(_ClinicalSummary):

    Location: generic.Location = Field(None)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)


class PatientQueryResponse(_ClinicalSummary):

    AdvanceDirectives: List[generic.AdvanceDirective] = Field(None)
    AdvanceDirectivesText: Union[str, None] = Field(None)
    Allergies: List[generic.Allergy] = Field(None)
    AllergyText: Union[str, None] = Field(None)
    Encounters: List[generic.Encounter] = Field(None)
    EncountersText: Union[str, None] = Field(None)
    FamilyHistory: List[generic.FamilyHistory] = Field(None)
    FamilyHistoryText: Union[str, None] = Field(None)
    FunctionalStatus: generic.FunctionalStatus = Field(None)
    FunctionalStatusText: Union[str, None] = Field(None)
    Goals: List[generic.Goal] = Field(None)
    GoalsText: Union[str, None] = Field(None)
    Header: generic.Header = Field(None)
    HealthConcerns: List[generic.HealthConcern] = Field(None)
    HealthConcernsText: Union[str, None] = Field(None)
    Immunizations: List[generic.Immunization] = Field(None)
    ImmunizationText: Union[str, None] = Field(None)
    Insurances: List[generic.Insurance] = Field(None)
    InsurancesText: Union[str, None] = Field(None)
    MedicalEquipment: List[generic.MedicalEquipment] = Field(None)
    MedicalEquipmentText: Union[str, None] = Field(None)
    Medications: List[generic.Medication] = Field(None)
    MedicationsText: Union[str, None] = Field(None)
    Meta: generic.Meta = Field(...)
    PlanOfCare: generic.PlanOfCare = Field(None)
    PlanOfCareText: Union[str, None] = Field(None)
    Problems: List[generic.Problem] = Field(None)
    ProblemsText: Union[str, None] = Field(None)
    Procedures: generic.Procedures = Field(None)
    ProceduresText: Union[str, None] = Field(None)
    ResolvedProblems: List[generic.ResolvedProblem] = Field(None)
    ResolvedProblemsText: Union[str, None] = Field(None)
    Results: List[generic.Result] = Field(None)
    ResultText: Union[str, None] = Field(None)
    SocialHistory: generic.SocialHistory = Field(None)
    SocialHistoryText: Union[str, None] = Field(None)
    VitalSigns: List[generic.VitalSign] = Field(None)
    VitalSignsText: Union[str, None] = Field(None)


class VisitPush(_ClinicalSummary):

    AdmissionDiagnosis: List[generic.AdmissionDiagnosis] = Field(None)
    AdmissionDiagnosisText: Union[str, None] = Field(None)
    AdvanceDirectives: List[generic.AdvanceDirective] = Field(None)
    AdvanceDirectivesText: Union[str, None] = Field(None)
    Allergies: List[generic.Allergy] = Field(None)
    AllergyText: Union[str, None] = Field(None)
    Assessment: generic.Assessment = Field(None)
    AssessmentText: Union[str, None] = Field(None)
    ChiefComplaintText: Union[str, None] = Field(None)
    DischargeDiagnosis: List[generic.DischargeDiagnosis] = Field(None)
    DischargeDiagnosisText: Union[str, None] = Field(None)
    DischargeMedications: List[generic.DischargeMedication] = Field(None)
    DischargeMedicationsText: Union[str, None] = Field(None)
    Encounters: List[generic.Encounter] = Field(None)
    EncountersText: Union[str, None] = Field(None)
    FamilyHistory: List[generic.FamilyHistory] = Field(None)
    FamilyHistoryText: Union[str, None] = Field(None)
    FunctionalStatus: generic.FunctionalStatus = Field(None)
    FunctionalStatusText: Union[str, None] = Field(None)
    Goals: List[generic.Goal] = Field(None)
    GoalsText: Union[str, None] = Field(None)
    Header: generic.Header = Field(None)
    HealthConcerns: List[generic.HealthConcern] = Field(None)
    HealthConcernsText: Union[str, None] = Field(None)
    HistoryOfPresentIllnessText: Union[str, None] = Field(None)
    Immunizations: List[generic.Immunization] = Field(None)
    ImmunizationText: Union[str, None] = Field(None)
    InstructionsText: Union[str, None] = Field(None)
    Insurances: List[generic.Insurance] = Field(None)
    InsurancesText: Union[str, None] = Field(None)
    InterventionsText: Union[str, None] = Field(None)
    MedicalEquipment: List[generic.MedicalEquipment] = Field(None)
    MedicalEquipmentText: Union[str, None] = Field(None)
    MedicalHistoryText: Union[str, None] = Field(None)
    Medications: List[generic.Medication] = Field(None)
    MedicationsAdministered: List[generic.MedicationsAdministered] = Field(None)
    MedicationsAdministeredText: Union[str, None] = Field(None)
    MedicationsText: Union[str, None] = Field(None)
    Meta: generic.Meta = Field(...)
    NoteSections: List[generic.NoteSection] = Field(None)
    ObjectiveText: Union[str, None] = Field(None)
    PhysicalExamText: Union[str, None] = Field(None)
    PlanOfCare: generic.PlanOfCare = Field(None)
    PlanOfCareText: Union[str, None] = Field(None)
    Problems: List[generic.Problem] = Field(None)
    ProblemsText: Union[str, None] = Field(None)
    Procedures: generic.Procedures = Field(None)
    ProceduresText: Union[str, None] = Field(None)
    ReasonForReferralText: Union[str, None] = Field(None)
    ReasonForVisit: List[generic.ReasonForVisit] = Field(None)
    ReasonForVisitText: Union[str, None] = Field(None)
    ResolvedProblems: List[generic.ResolvedProblem] = Field(None)
    ResolvedProblemsText: Union[str, None] = Field(None)
    Results: List[generic.Result] = Field(None)
    ResultText: Union[str, None] = Field(None)
    ReviewOfSystemsText: Union[str, None] = Field(None)
    SocialHistory: generic.SocialHistory = Field(None)
    SocialHistoryText: Union[str, None] = Field(None)
    SubjectiveText: Union[str, None] = Field(None)
    VitalSigns: List[generic.VitalSign] = Field(None)
    VitalSignsText: Union[str, None] = Field(None)


class VisitQuery(_ClinicalSummary):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class VisitQueryResponse(_ClinicalSummary):

    AdmissionDiagnosis: List[generic.AdmissionDiagnosis] = Field(None)
    AdmissionDiagnosisText: Union[str, None] = Field(None)
    AdvanceDirectives: List[generic.AdvanceDirective] = Field(None)
    AdvanceDirectivesText: Union[str, None] = Field(None)
    Allergies: List[generic.Allergy] = Field(None)
    AllergyText: Union[str, None] = Field(None)
    Assessment: generic.Assessment = Field(None)
    AssessmentText: Union[str, None] = Field(None)
    ChiefComplaintText: Union[str, None] = Field(None)
    DischargeDiagnosis: List[generic.DischargeDiagnosis] = Field(None)
    DischargeDiagnosisText: Union[str, None] = Field(None)
    DischargeMedications: List[generic.DischargeMedication] = Field(None)
    DischargeMedicationsText: Union[str, None] = Field(None)
    Encounters: List[generic.Encounter] = Field(None)
    EncountersText: Union[str, None] = Field(None)
    FamilyHistory: List[generic.FamilyHistory] = Field(None)
    FamilyHistoryText: Union[str, None] = Field(None)
    FunctionalStatus: generic.FunctionalStatus = Field(None)
    FunctionalStatusText: Union[str, None] = Field(None)
    Goals: List[generic.Goal] = Field(None)
    GoalsText: Union[str, None] = Field(None)
    Header: generic.Header = Field(None)
    HealthConcerns: List[generic.HealthConcern] = Field(None)
    HealthConcernsText: Union[str, None] = Field(None)
    HistoryOfPresentIllnessText: Union[str, None] = Field(None)
    Immunizations: List[generic.Immunization] = Field(None)
    ImmunizationText: Union[str, None] = Field(None)
    InstructionsText: Union[str, None] = Field(None)
    Insurances: List[generic.Insurance] = Field(None)
    InsurancesText: Union[str, None] = Field(None)
    InterventionsText: Union[str, None] = Field(None)
    MedicalEquipment: List[generic.MedicalEquipment] = Field(None)
    MedicalEquipmentText: Union[str, None] = Field(None)
    Medications: List[generic.Medication] = Field(None)
    MedicationsAdministered: List[generic.MedicationsAdministered] = Field(None)
    MedicationsAdministeredText: Union[str, None] = Field(None)
    MedicationsText: Union[str, None] = Field(None)
    Meta: generic.Meta = Field(...)
    ObjectiveText: Union[str, None] = Field(None)
    PhysicalExamText: Union[str, None] = Field(None)
    PlanOfCare: generic.PlanOfCare = Field(None)
    PlanOfCareText: Union[str, None] = Field(None)
    Problems: List[generic.Problem] = Field(None)
    ProblemsText: Union[str, None] = Field(None)
    Procedures: generic.Procedures = Field(None)
    ProceduresText: Union[str, None] = Field(None)
    ReasonForReferralText: Union[str, None] = Field(None)
    ReasonForVisit: List[generic.ReasonForVisit] = Field(None)
    ReasonForVisitText: Union[str, None] = Field(None)
    ResolvedProblems: List[generic.ResolvedProblem] = Field(None)
    ResolvedProblemsText: Union[str, None] = Field(None)
    Results: List[generic.Result] = Field(None)
    ResultText: Union[str, None] = Field(None)
    ReviewOfSystemsText: Union[str, None] = Field(None)
    SocialHistory: generic.SocialHistory = Field(None)
    SocialHistoryText: Union[str, None] = Field(None)
    SubjectiveText: Union[str, None] = Field(None)
    VitalSigns: List[generic.VitalSign] = Field(None)
    VitalSignsText: Union[str, None] = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Replace(EventTypeAbstractModel):

    Media: "ReplaceMedia" = Field(...)
    Meta: "ReplaceMeta" = Field(...)
    Orders: List["ReplaceOrder"] = Field(None)
    Patient: "ReplacePatient" = Field(...)
    Visit: "ReplaceVisit" = Field(None)


class ReplaceMedia(RedoxAbstractModel):

    Authenticated: Union[str, None] = Field(None)
    Authenticator: "ReplaceMediaAuthenticator" = Field(None)
    Availability: str = Field(...)
    CreationDateTime: Union[str, None] = Field(None)
    DirectAddressFrom: Union[str, None] = Field(None)
    DirectAddressTo: Union[str, None] = Field(None)
    DocumentDescription: Union[str, None] = Field(None)
    DocumentID: str = Field(...)
    DocumentType: str = Field(...)
    FileContents: str = Field(...)
    FileName: str = Field(...)
    FileType: str = Field(...)
    Notifications: List["ReplaceMediaNotification"] = Field(None)
    OriginalDocumentID: str = Field(...)
    Provider: "ReplaceMediaProvider" = Field(...)
    ServiceDateTime: Union[str, None] = Field(None)


class ReplaceMediaAuthenticator(RedoxAbstractModel):

    Address: "ReplaceMediaAuthenticatorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceMediaAuthenticatorLocation" = Field(None)
    PhoneNumber: "ReplaceMediaAuthenticatorPhoneNumber" = Field(None)


class ReplaceMediaAuthenticatorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceMediaAuthenticatorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceMediaAuthenticatorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceMediaNotification(RedoxAbstractModel):

    Address: "ReplaceMediaNotificationAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceMediaNotificationLocation" = Field(None)
    PhoneNumber: "ReplaceMediaNotificationPhoneNumber" = Field(None)


class ReplaceMediaNotificationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceMediaNotificationLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceMediaNotificationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceMediaProvider(RedoxAbstractModel):

    Address: "ReplaceMediaProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ReplaceMediaProviderLocation" = Field(None)
    PhoneNumber: "ReplaceMediaProviderPhoneNumber" = Field(None)


class ReplaceMediaProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplaceMediaProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ReplaceMediaProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ReplaceMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["ReplaceMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["ReplaceMetaLog"] = Field(None)
    Message: "ReplaceMetaMessage" = Field(None)
    Source: "ReplaceMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "ReplaceMetaTransmission" = Field(None)


class ReplaceMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ReplaceMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class ReplaceMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ReplaceMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ReplaceMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ReplaceOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ReplacePatient(RedoxAbstractModel):

    Demographics: "ReplacePatientDemographics" = Field(None)
    Identifiers: List["ReplacePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class ReplacePatientDemographics(RedoxAbstractModel):

    Address: "ReplacePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "ReplacePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class ReplacePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ReplacePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class ReplacePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class ReplaceVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    Location: "ReplaceVisitLocation" = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class ReplaceVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


Replace.update_forward_refs()
ReplaceMedia.update_forward_refs()
ReplaceMediaAuthenticator.update_forward_refs()
ReplaceMediaNotification.update_forward_refs()
ReplaceMediaProvider.update_forward_refs()
ReplaceMeta.update_forward_refs()
ReplacePatient.update_forward_refs()
ReplacePatientDemographics.update_forward_refs()
ReplaceVisit.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Modify(EventTypeAbstractModel):

    Meta: "ModifyMeta" = Field(...)
    Patient: "ModifyPatient" = Field(...)
    Referral: "ModifyReferral" = Field(None)
    Visit: "ModifyVisit" = Field(None)


class ModifyMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["ModifyMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["ModifyMetaLog"] = Field(None)
    Message: "ModifyMetaMessage" = Field(None)
    Source: "ModifyMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "ModifyMetaTransmission" = Field(None)


class ModifyMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ModifyMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class ModifyMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ModifyMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ModifyMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ModifyPatient(RedoxAbstractModel):

    Contacts: List["ModifyPatientContact"] = Field(None)
    Demographics: "ModifyPatientDemographics" = Field(None)
    Guarantor: "ModifyPatientGuarantor" = Field(None)
    Identifiers: List["ModifyPatientIdentifier"] = Field(...)
    Insurances: List["ModifyPatientInsurance"] = Field(None)
    Notes: List[str] = Field(None)


class ModifyPatientContact(RedoxAbstractModel):

    Address: "ModifyPatientContactAddress" = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "ModifyPatientContactPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Roles: List[str] = Field(None)


class ModifyPatientContactAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyPatientContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class ModifyPatientDemographics(RedoxAbstractModel):

    Address: "ModifyPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "ModifyPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class ModifyPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class ModifyPatientGuarantor(RedoxAbstractModel):

    Address: "ModifyPatientGuarantorAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Employer: "ModifyPatientGuarantorEmployer" = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Number: Union[str, None] = Field(None)
    PhoneNumber: "ModifyPatientGuarantorPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    Spouse: "ModifyPatientGuarantorSpouse" = Field(None)
    SSN: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ModifyPatientGuarantorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyPatientGuarantorEmployer(RedoxAbstractModel):

    Address: "ModifyPatientGuarantorEmployerAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class ModifyPatientGuarantorEmployerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyPatientGuarantorPhoneNumber(RedoxAbstractModel):

    Business: Union[str, None] = Field(None)
    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class ModifyPatientGuarantorSpouse(RedoxAbstractModel):

    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class ModifyPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class ModifyPatientInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "ModifyPatientInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "ModifyPatientInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "ModifyPatientInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class ModifyPatientInsuranceCompany(RedoxAbstractModel):

    Address: "ModifyPatientInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class ModifyPatientInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyPatientInsuranceInsured(RedoxAbstractModel):

    Address: "ModifyPatientInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["ModifyPatientInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class ModifyPatientInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyPatientInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ModifyPatientInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ModifyReferral(RedoxAbstractModel):

    AlternateID: Union[str, None] = Field(None)
    Authorization: "ModifyReferralAuthorization" = Field(None)
    Category: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    DepartmentSpecialty: Union[str, None] = Field(None)
    Diagnoses: List["ModifyReferralDiagnosis"] = Field(None)
    ExpirationDateTime: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Priority: Union[str, None] = Field(None)
    Procedures: List["ModifyReferralProcedure"] = Field(None)
    ProcessDateTime: Union[str, None] = Field(None)
    Providers: List["ModifyReferralProvider"] = Field(None)
    ProviderSpecialty: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Visit: "ModifyReferralVisit" = Field(None)


class ModifyReferralAuthorization(RedoxAbstractModel):

    AuthorizedTreatmentCount: Union[str, None] = Field(None)
    Company: "ModifyReferralAuthorizationCompany" = Field(None)
    DateTime: Union[str, None] = Field(None)
    ExpirationDateTime: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Number: Union[str, None] = Field(None)
    Plan: "ModifyReferralAuthorizationPlan" = Field(None)
    ReimbursementLimit: Union[str, None] = Field(None)
    RequestedTreatmentCount: Union[str, None] = Field(None)
    RequestedTreatmentUnits: Union[str, None] = Field(None)


class ModifyReferralAuthorizationCompany(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ModifyReferralAuthorizationPlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ModifyReferralDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Type: Union[str, None] = Field(None)


class ModifyReferralProcedure(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Modifiers: List[str] = Field(None)
    Notes: List[str] = Field(None)
    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class ModifyReferralProvider(RedoxAbstractModel):

    Address: "ModifyReferralProviderAddress" = Field(None)
    ContactInfo: Union[str, None] = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "ModifyReferralProviderLocation" = Field(None)
    PhoneNumber: "ModifyReferralProviderPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class ModifyReferralProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ModifyReferralProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ModifyReferralProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ModifyReferralVisit(RedoxAbstractModel):

    VisitNumber: Union[str, None] = Field(None)


class ModifyVisit(RedoxAbstractModel):

    VisitNumber: Union[str, None] = Field(None)


Modify.update_forward_refs()
ModifyMeta.update_forward_refs()
ModifyPatient.update_forward_refs()
ModifyPatientContact.update_forward_refs()
ModifyPatientDemographics.update_forward_refs()
ModifyPatientGuarantor.update_forward_refs()
ModifyPatientGuarantorEmployer.update_forward_refs()
ModifyPatientInsurance.update_forward_refs()
ModifyPatientInsuranceCompany.update_forward_refs()
ModifyPatientInsuranceInsured.update_forward_refs()
ModifyReferral.update_forward_refs()
ModifyReferralAuthorization.update_forward_refs()
ModifyReferralProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import surgicalscheduling
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _SurgicalScheduling(GenericRedoxAbstractModel):
    _redox_module = surgicalscheduling


class Cancel(_SurgicalScheduling):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Procedures: List[generic.Procedure] = Field(...)
    SurgeryStaff: List[generic.SurgeryStaff] = Field(None)
    SurgicalCase: generic.SurgicalCase = Field(None)
    SurgicalInfo: List[generic.SurgicalInfo] = Field(None)
    Visit: generic.Visit = Field(...)


class Modification(_SurgicalScheduling):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Procedures: List[generic.Procedure] = Field(...)
    SurgeryStaff: List[generic.SurgeryStaff] = Field(None)
    SurgicalCase: generic.SurgicalCase = Field(None)
    SurgicalInfo: List[generic.SurgicalInfo] = Field(None)
    Visit: generic.Visit = Field(...)


class New(_SurgicalScheduling):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Procedures: List[generic.Procedure] = Field(...)
    SurgeryStaff: List[generic.SurgeryStaff] = Field(None)
    SurgicalCase: generic.SurgicalCase = Field(None)
    SurgicalInfo: List[generic.SurgicalInfo] = Field(None)
    Visit: generic.Visit = Field(...)


class NoShow(_SurgicalScheduling):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Procedures: List[generic.Procedure] = Field(...)
    SurgeryStaff: List[generic.SurgeryStaff] = Field(None)
    SurgicalCase: generic.SurgicalCase = Field(None)
    SurgicalInfo: List[generic.SurgicalInfo] = Field(None)
    Visit: generic.Visit = Field(...)


class Reschedule(_SurgicalScheduling):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Procedures: List[generic.Procedure] = Field(...)
    SurgeryStaff: List[generic.SurgeryStaff] = Field(None)
    SurgicalCase: generic.SurgicalCase = Field(None)
    SurgicalInfo: List[generic.SurgicalInfo] = Field(None)
    Visit: generic.Visit = Field(...)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class VisitQueryResponse(EventTypeAbstractModel):

    Meta: "VisitQueryResponseMeta" = Field(...)
    Patients: List["VisitQueryResponsePatient"] = Field(None)


class VisitQueryResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["VisitQueryResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["VisitQueryResponseMetaLog"] = Field(None)
    Message: "VisitQueryResponseMetaMessage" = Field(None)
    Source: "VisitQueryResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "VisitQueryResponseMetaTransmission" = Field(None)


class VisitQueryResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitQueryResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class VisitQueryResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class VisitQueryResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class VisitQueryResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class VisitQueryResponsePatient(RedoxAbstractModel):

    Demographics: "VisitQueryResponsePatientDemographics" = Field(None)
    Identifiers: List["VisitQueryResponsePatientIdentifier"] = Field(None)
    Visits: List["VisitQueryResponsePatientVisit"] = Field(None)


class VisitQueryResponsePatientDemographics(RedoxAbstractModel):

    Address: "VisitQueryResponsePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "VisitQueryResponsePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class VisitQueryResponsePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class VisitQueryResponsePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class VisitQueryResponsePatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class VisitQueryResponsePatientVisit(RedoxAbstractModel):

    Location: "VisitQueryResponsePatientVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class VisitQueryResponsePatientVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


VisitQueryResponse.update_forward_refs()
VisitQueryResponseMeta.update_forward_refs()
VisitQueryResponsePatient.update_forward_refs()
VisitQueryResponsePatientDemographics.update_forward_refs()
VisitQueryResponsePatientVisit.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class SubjectUpdate(EventTypeAbstractModel):

    Enrollment: "SubjectUpdateEnrollment" = Field(None)
    Meta: "SubjectUpdateMeta" = Field(...)
    Patient: "SubjectUpdatePatient" = Field(None)
    Study: "SubjectUpdateStudy" = Field(None)


class SubjectUpdateEnrollment(RedoxAbstractModel):

    Coordinators: List["SubjectUpdateEnrollmentCoordinator"] = Field(None)
    EndDateTime: Union[str, None] = Field(None)
    StartDateTime: Union[str, None] = Field(None)
    SubjectStatus: Union[str, None] = Field(None)


class SubjectUpdateEnrollmentCoordinator(RedoxAbstractModel):

    Address: "SubjectUpdateEnrollmentCoordinatorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "SubjectUpdateEnrollmentCoordinatorLocation" = Field(None)
    PhoneNumber: "SubjectUpdateEnrollmentCoordinatorPhoneNumber" = Field(None)


class SubjectUpdateEnrollmentCoordinatorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubjectUpdateEnrollmentCoordinatorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubjectUpdateEnrollmentCoordinatorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class SubjectUpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["SubjectUpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["SubjectUpdateMetaLog"] = Field(None)
    Message: "SubjectUpdateMetaMessage" = Field(None)
    Source: "SubjectUpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "SubjectUpdateMetaTransmission" = Field(None)


class SubjectUpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class SubjectUpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class SubjectUpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class SubjectUpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class SubjectUpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class SubjectUpdatePatient(RedoxAbstractModel):

    Demographics: "SubjectUpdatePatientDemographics" = Field(None)
    Identifiers: List["SubjectUpdatePatientIdentifier"] = Field(None)
    Notes: List[str] = Field(None)


class SubjectUpdatePatientDemographics(RedoxAbstractModel):

    Address: "SubjectUpdatePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "SubjectUpdatePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class SubjectUpdatePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubjectUpdatePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class SubjectUpdatePatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubjectUpdateStudy(RedoxAbstractModel):

    Identifiers: List["SubjectUpdateStudyIdentifier"] = Field(None)
    Title: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubjectUpdateStudyIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


SubjectUpdate.update_forward_refs()
SubjectUpdateEnrollment.update_forward_refs()
SubjectUpdateEnrollmentCoordinator.update_forward_refs()
SubjectUpdateMeta.update_forward_refs()
SubjectUpdatePatient.update_forward_refs()
SubjectUpdatePatientDemographics.update_forward_refs()
SubjectUpdateStudy.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import patientsearch
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _PatientSearch(GenericRedoxAbstractModel):
    _redox_module = patientsearch


class LocationQuery(_PatientSearch):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)


class LocationQueryResponse(_PatientSearch):

    Meta: generic.Meta = Field(...)
    Patients: List[generic.Patient] = Field(...)


class Query(_PatientSearch):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)


class Response(_PatientSearch):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)
    PotentialMatches: List[generic.PotentialMatch] = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class New(EventTypeAbstractModel):

    Device: "NewDevice" = Field(...)
    Meta: "NewMeta" = Field(...)
    Observations: List["NewObservation"] = Field(...)
    Patient: "NewPatient" = Field(None)
    Visit: "NewVisit" = Field(None)


class NewDevice(RedoxAbstractModel):

    ID: str = Field(...)


class NewMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["NewMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["NewMetaLog"] = Field(None)
    Message: "NewMetaMessage" = Field(None)
    Source: "NewMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "NewMetaTransmission" = Field(None)


class NewMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class NewMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NewMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NewObservation(RedoxAbstractModel):

    Code: str = Field(...)
    DateTime: str = Field(...)
    Units: Union[str, None] = Field(None)
    Value: str = Field(...)
    ValueType: str = Field(...)


class NewPatient(RedoxAbstractModel):

    Contacts: List["NewPatientContact"] = Field(None)
    Demographics: "NewPatientDemographics" = Field(None)
    Identifiers: List["NewPatientIdentifier"] = Field(None)
    Notes: List[str] = Field(None)


class NewPatientContact(RedoxAbstractModel):

    Address: "NewPatientContactAddress" = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "NewPatientContactPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Roles: List[str] = Field(None)


class NewPatientContactAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NewPatientContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class NewPatientDemographics(RedoxAbstractModel):

    Address: "NewPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "NewPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class NewPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NewPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class NewPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewVisit(RedoxAbstractModel):

    Location: "NewVisitLocation" = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class NewVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


New.update_forward_refs()
NewMeta.update_forward_refs()
NewPatient.update_forward_refs()
NewPatientContact.update_forward_refs()
NewPatientDemographics.update_forward_refs()
NewVisit.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Update(EventTypeAbstractModel):

    Education: List["UpdateEducation"] = Field(...)
    Meta: "UpdateMeta" = Field(...)
    Patient: "UpdatePatient" = Field(...)
    Visit: "UpdateVisit" = Field(None)


class UpdateEducation(RedoxAbstractModel):

    ActionDateTime: Union[str, None] = Field(None)
    ActionStatus: Union[str, None] = Field(None)
    Assignments: List["UpdateEducationAssignment"] = Field(None)
    CreatedDateTime: Union[str, None] = Field(None)
    InstanceID: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Subject: "UpdateEducationSubject" = Field(...)


class UpdateEducationAssignment(RedoxAbstractModel):

    ActionDateTime: Union[str, None] = Field(None)
    ActionStatus: Union[str, None] = Field(None)
    Assignees: List["UpdateEducationAssignmentAssignee"] = Field(None)
    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    CreatedDateTime: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    InstanceID: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Topic: "UpdateEducationAssignmentTopic" = Field(None)


class UpdateEducationAssignmentAssignee(RedoxAbstractModel):

    ContentType: Union[str, None] = Field(None)
    Learner: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Readiness: Union[str, None] = Field(None)
    Response: Union[str, None] = Field(None)


class UpdateEducationAssignmentTopic(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class UpdateEducationSubject(RedoxAbstractModel):

    Code: str = Field(...)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class UpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["UpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["UpdateMetaLog"] = Field(None)
    Message: "UpdateMetaMessage" = Field(None)
    Source: "UpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "UpdateMetaTransmission" = Field(None)


class UpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class UpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdatePatient(RedoxAbstractModel):

    Demographics: "UpdatePatientDemographics" = Field(None)
    Identifiers: List["UpdatePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class UpdatePatientDemographics(RedoxAbstractModel):

    Address: "UpdatePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "UpdatePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class UpdatePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdatePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class UpdatePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class UpdateVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AttendingProvider: "UpdateVisitAttendingProvider" = Field(None)
    ConsultingProvider: "UpdateVisitConsultingProvider" = Field(None)
    Location: "UpdateVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    ReferringProvider: "UpdateVisitReferringProvider" = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class UpdateVisitAttendingProvider(RedoxAbstractModel):

    Address: "UpdateVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateVisitAttendingProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "UpdateVisitAttendingProviderPhoneNumber" = Field(None)


class UpdateVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateVisitConsultingProvider(RedoxAbstractModel):

    Address: "UpdateVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateVisitConsultingProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "UpdateVisitConsultingProviderPhoneNumber" = Field(None)


class UpdateVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitReferringProvider(RedoxAbstractModel):

    Address: "UpdateVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateVisitReferringProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "UpdateVisitReferringProviderPhoneNumber" = Field(None)


class UpdateVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


Update.update_forward_refs()
UpdateEducation.update_forward_refs()
UpdateEducationAssignment.update_forward_refs()
UpdateMeta.update_forward_refs()
UpdatePatient.update_forward_refs()
UpdatePatientDemographics.update_forward_refs()
UpdateVisit.update_forward_refs()
UpdateVisitAttendingProvider.update_forward_refs()
UpdateVisitConsultingProvider.update_forward_refs()
UpdateVisitReferringProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class PreAdmit(EventTypeAbstractModel):

    Meta: "PreAdmitMeta" = Field(...)
    Patient: "PreAdmitPatient" = Field(...)
    Visit: "PreAdmitVisit" = Field(None)


class PreAdmitMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["PreAdmitMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["PreAdmitMetaLog"] = Field(None)
    Message: "PreAdmitMetaMessage" = Field(None)
    Source: "PreAdmitMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "PreAdmitMetaTransmission" = Field(None)


class PreAdmitMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PreAdmitMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class PreAdmitMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PreAdmitMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PreAdmitMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PreAdmitPatient(RedoxAbstractModel):

    Allergies: List["PreAdmitPatientAllergy"] = Field(None)
    Contacts: List["PreAdmitPatientContact"] = Field(None)
    Demographics: "PreAdmitPatientDemographics" = Field(None)
    Diagnoses: List["PreAdmitPatientDiagnosis"] = Field(None)
    Identifiers: List["PreAdmitPatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)
    PCP: "PreAdmitPatientPCP" = Field(None)


class PreAdmitPatientAllergy(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    OnsetDateTime: Union[str, None] = Field(None)
    Reaction: List["PreAdmitPatientAllergyReaction"] = Field(None)
    Severity: "PreAdmitPatientAllergySeverity" = Field(None)
    Status: Union[str, None] = Field(None)
    Type: "PreAdmitPatientAllergyType" = Field(None)


class PreAdmitPatientAllergyReaction(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PreAdmitPatientAllergySeverity(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PreAdmitPatientAllergyType(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PreAdmitPatientContact(RedoxAbstractModel):

    Address: "PreAdmitPatientContactAddress" = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "PreAdmitPatientContactPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Roles: List[str] = Field(None)


class PreAdmitPatientContactAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitPatientContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class PreAdmitPatientDemographics(RedoxAbstractModel):

    Address: "PreAdmitPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "PreAdmitPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PreAdmitPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class PreAdmitPatientDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class PreAdmitPatientPCP(RedoxAbstractModel):

    Address: "PreAdmitPatientPCPAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PreAdmitPatientPCPLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "PreAdmitPatientPCPPhoneNumber" = Field(None)


class PreAdmitPatientPCPAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitPatientPCPLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitPatientPCPPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PreAdmitVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["PreAdmitVisitAdditionalStaff"] = Field(None)
    AdmittingProvider: "PreAdmitVisitAdmittingProvider" = Field(None)
    AttendingProvider: "PreAdmitVisitAttendingProvider" = Field(None)
    Balance: Union[Number, None] = Field(None)
    ConsultingProvider: "PreAdmitVisitConsultingProvider" = Field(None)
    DiagnosisRelatedGroup: Union[Number, None] = Field(None)
    DiagnosisRelatedGroupType: Union[Number, None] = Field(None)
    Duration: Union[Number, None] = Field(None)
    Guarantor: "PreAdmitVisitGuarantor" = Field(None)
    Instructions: List[str] = Field(None)
    Insurances: List["PreAdmitVisitInsurance"] = Field(None)
    Location: "PreAdmitVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    ReferringProvider: "PreAdmitVisitReferringProvider" = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class PreAdmitVisitAdditionalStaff(RedoxAbstractModel):

    Address: "PreAdmitVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PreAdmitVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "PreAdmitVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "PreAdmitVisitAdditionalStaffRole" = Field(None)


class PreAdmitVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PreAdmitVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class PreAdmitVisitAdmittingProvider(RedoxAbstractModel):

    Address: "PreAdmitVisitAdmittingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PreAdmitVisitAdmittingProviderLocation" = Field(None)
    PhoneNumber: "PreAdmitVisitAdmittingProviderPhoneNumber" = Field(None)


class PreAdmitVisitAdmittingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitAdmittingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitAdmittingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PreAdmitVisitAttendingProvider(RedoxAbstractModel):

    Address: "PreAdmitVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PreAdmitVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "PreAdmitVisitAttendingProviderPhoneNumber" = Field(None)


class PreAdmitVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PreAdmitVisitConsultingProvider(RedoxAbstractModel):

    Address: "PreAdmitVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PreAdmitVisitConsultingProviderLocation" = Field(None)
    PhoneNumber: "PreAdmitVisitConsultingProviderPhoneNumber" = Field(None)


class PreAdmitVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class PreAdmitVisitGuarantor(RedoxAbstractModel):

    Address: "PreAdmitVisitGuarantorAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Employer: "PreAdmitVisitGuarantorEmployer" = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Number: Union[str, None] = Field(None)
    PhoneNumber: "PreAdmitVisitGuarantorPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    Spouse: "PreAdmitVisitGuarantorSpouse" = Field(None)
    SSN: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitGuarantorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitGuarantorEmployer(RedoxAbstractModel):

    Address: "PreAdmitVisitGuarantorEmployerAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class PreAdmitVisitGuarantorEmployerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitGuarantorPhoneNumber(RedoxAbstractModel):

    Business: Union[str, None] = Field(None)
    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class PreAdmitVisitGuarantorSpouse(RedoxAbstractModel):

    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class PreAdmitVisitInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "PreAdmitVisitInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "PreAdmitVisitInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "PreAdmitVisitInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class PreAdmitVisitInsuranceCompany(RedoxAbstractModel):

    Address: "PreAdmitVisitInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class PreAdmitVisitInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitInsuranceInsured(RedoxAbstractModel):

    Address: "PreAdmitVisitInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["PreAdmitVisitInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class PreAdmitVisitInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class PreAdmitVisitInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitLocation(RedoxAbstractModel):

    Address: "PreAdmitVisitLocationAddress" = Field(None)
    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitReferringProvider(RedoxAbstractModel):

    Address: "PreAdmitVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "PreAdmitVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "PreAdmitVisitReferringProviderPhoneNumber" = Field(None)


class PreAdmitVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PreAdmitVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PreAdmitVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


PreAdmit.update_forward_refs()
PreAdmitMeta.update_forward_refs()
PreAdmitPatient.update_forward_refs()
PreAdmitPatientAllergy.update_forward_refs()
PreAdmitPatientContact.update_forward_refs()
PreAdmitPatientDemographics.update_forward_refs()
PreAdmitPatientPCP.update_forward_refs()
PreAdmitVisit.update_forward_refs()
PreAdmitVisitAdditionalStaff.update_forward_refs()
PreAdmitVisitAdmittingProvider.update_forward_refs()
PreAdmitVisitAttendingProvider.update_forward_refs()
PreAdmitVisitConsultingProvider.update_forward_refs()
PreAdmitVisitGuarantor.update_forward_refs()
PreAdmitVisitGuarantorEmployer.update_forward_refs()
PreAdmitVisitInsurance.update_forward_refs()
PreAdmitVisitInsuranceCompany.update_forward_refs()
PreAdmitVisitInsuranceInsured.update_forward_refs()
PreAdmitVisitLocation.update_forward_refs()
PreAdmitVisitReferringProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import media
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Media(GenericRedoxAbstractModel):
    _redox_module = media


class Delete(_Media):

    Media: generic.Media = Field(...)
    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(None)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class New(_Media):

    Media: generic.Media = Field(...)
    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(None)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class Query(_Media):

    DocumentIDs: List[str] = Field(None)
    DocumentTypes: List[str] = Field(None)
    Meta: generic.Meta = Field(...)
    Patients: List[generic.Patient] = Field(None)
    VisitNumbers: List[str] = Field(None)


class QueryResponse(_Media):

    Media: List[generic.Medium] = Field(None)
    Meta: generic.Meta = Field(...)


class Replace(_Media):

    Media: generic.Media = Field(...)
    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(None)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class CensusQueryResponse(EventTypeAbstractModel):

    Meta: "CensusQueryResponseMeta" = Field(...)
    Patients: List["CensusQueryResponsePatient"] = Field(None)


class CensusQueryResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["CensusQueryResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["CensusQueryResponseMetaLog"] = Field(None)
    Message: "CensusQueryResponseMetaMessage" = Field(None)
    Source: "CensusQueryResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "CensusQueryResponseMetaTransmission" = Field(None)


class CensusQueryResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class CensusQueryResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class CensusQueryResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class CensusQueryResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class CensusQueryResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class CensusQueryResponsePatient(RedoxAbstractModel):

    Demographics: "CensusQueryResponsePatientDemographics" = Field(None)
    Identifiers: List["CensusQueryResponsePatientIdentifier"] = Field(None)
    Visits: List["CensusQueryResponsePatientVisit"] = Field(None)


class CensusQueryResponsePatientDemographics(RedoxAbstractModel):

    Address: "CensusQueryResponsePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "CensusQueryResponsePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class CensusQueryResponsePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CensusQueryResponsePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class CensusQueryResponsePatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class CensusQueryResponsePatientVisit(RedoxAbstractModel):

    Location: "CensusQueryResponsePatientVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class CensusQueryResponsePatientVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


CensusQueryResponse.update_forward_refs()
CensusQueryResponseMeta.update_forward_refs()
CensusQueryResponsePatient.update_forward_refs()
CensusQueryResponsePatientDemographics.update_forward_refs()
CensusQueryResponsePatientVisit.update_forward_refs()



# -*- coding: utf-8 -*-
# flake8: noqa: F401
from .administration import Administration
from .new import New
from .patientquery import PatientQuery
from .patientqueryresponse import PatientQueryResponse



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import results
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Results(GenericRedoxAbstractModel):
    _redox_module = results


class New(_Results):

    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class NewUnsolicited(_Results):

    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(...)
    Patient: generic.Patient = Field(...)
    Visit: generic.Visit = Field(None)


class Query(_Results):

    Completion: generic.Completion = Field(None)
    LastUpdated: generic.LastUpdated = Field(None)
    Location: generic.Location = Field(None)
    Meta: generic.Meta = Field(...)
    OrderIDs: List[str] = Field(None)
    Patients: List[generic.Patient] = Field(None)
    Procedures: List[generic.Procedure] = Field(None)
    ResultStatuses: List[str] = Field(None)


class QueryResponse(_Results):

    Meta: generic.Meta = Field(...)
    Orders: List[generic.Order] = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class PushSlots(EventTypeAbstractModel):

    Meta: "PushSlotsMeta" = Field(...)
    Slots: List["PushSlotsSlot"] = Field(...)


class PushSlotsMeta(RedoxAbstractModel):

    BatchID: Union[str, None] = Field(None)
    CurrentBatch: Union[str, None] = Field(None)
    DataModel: str = Field(...)
    Destinations: List["PushSlotsMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["PushSlotsMetaLog"] = Field(None)
    Message: "PushSlotsMetaMessage" = Field(None)
    Source: "PushSlotsMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    TotalBatches: Union[str, None] = Field(None)
    Transmission: "PushSlotsMetaTransmission" = Field(None)


class PushSlotsMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PushSlotsMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class PushSlotsMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PushSlotsMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class PushSlotsMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class PushSlotsSlot(RedoxAbstractModel):

    DateTime: str = Field(...)
    Duration: Number = Field(...)
    ID: Union[str, None] = Field(None)
    Location: "PushSlotsSlotLocation" = Field(None)
    Provider: "PushSlotsSlotProvider" = Field(None)
    Reason: Union[str, None] = Field(None)


class PushSlotsSlotLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class PushSlotsSlotProvider(RedoxAbstractModel):

    Address: "PushSlotsSlotProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    PhoneNumber: "PushSlotsSlotProviderPhoneNumber" = Field(None)


class PushSlotsSlotProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class PushSlotsSlotProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


PushSlots.update_forward_refs()
PushSlotsMeta.update_forward_refs()
PushSlotsSlot.update_forward_refs()
PushSlotsSlotProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# flake8: noqa: F401
from .documentget import DocumentGet
from .documentgetresponse import DocumentGetResponse
from .documentquery import DocumentQuery
from .documentqueryresponse import DocumentQueryResponse
from .patientpush import PatientPush
from .patientquery import PatientQuery
from .patientqueryresponse import PatientQueryResponse
from .visitpush import VisitPush
from .visitquery import VisitQuery
from .visitqueryresponse import VisitQueryResponse



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel


class SignOn(EventTypeAbstractModel):

    EmailAddress: Union[str, None] = Field(None)
    Expiration: str = Field(...)
    FirstName: Union[str, None] = Field(None)
    IssuedAt: str = Field(...)
    LastName: Union[str, None] = Field(None)
    Locale: Union[str, None] = Field(None)
    Meta: "SignOnMeta" = Field(...)
    MiddleName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    NPI: Union[str, None] = Field(None)
    Order: "SignOnOrder" = Field(None)
    Patient: "SignOnPatient" = Field(None)
    PhoneNumber: "SignOnPhoneNumber" = Field(None)
    ProviderSpecialty: Union[str, None] = Field(None)
    Subject: str = Field(...)
    TimeZone: Union[str, None] = Field(None)
    UserId: Union[str, None] = Field(None)
    Visit: "SignOnVisit" = Field(None)


class SignOnMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["SignOnMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    SessionBaseURL: Union[str, None] = Field(None)
    SessionID: Union[str, None] = Field(None)
    Source: "SignOnMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)


class SignOnMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class SignOnMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class SignOnOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)


class SignOnPatient(RedoxAbstractModel):

    Demographics: "SignOnPatientDemographics" = Field(None)
    Identifiers: List["SignOnPatientIdentifier"] = Field(None)


class SignOnPatientDemographics(RedoxAbstractModel):

    Address: "SignOnPatientDemographicsAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "SignOnPatientDemographicsPhoneNumber" = Field(None)
    Sex: Union[str, None] = Field(None)


class SignOnPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SignOnPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class SignOnPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SignOnPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class SignOnVisit(RedoxAbstractModel):

    Location: "SignOnVisitLocation" = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class SignOnVisitLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


SignOn.update_forward_refs()
SignOnMeta.update_forward_refs()
SignOnPatient.update_forward_refs()
SignOnPatientDemographics.update_forward_refs()
SignOnVisit.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class AvailableSlots(EventTypeAbstractModel):

    EndDateTime: Union[str, None] = Field(None)
    Meta: "AvailableSlotsMeta" = Field(...)
    Patient: "AvailableSlotsPatient" = Field(None)
    StartDateTime: str = Field(...)
    Visit: "AvailableSlotsVisit" = Field(None)


class AvailableSlotsMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["AvailableSlotsMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["AvailableSlotsMetaLog"] = Field(None)
    Message: "AvailableSlotsMetaMessage" = Field(None)
    Source: "AvailableSlotsMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "AvailableSlotsMetaTransmission" = Field(None)


class AvailableSlotsMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AvailableSlotsMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class AvailableSlotsMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class AvailableSlotsMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AvailableSlotsMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class AvailableSlotsPatient(RedoxAbstractModel):

    Identifiers: List["AvailableSlotsPatientIdentifier"] = Field(None)


class AvailableSlotsPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class AvailableSlotsVisit(RedoxAbstractModel):

    AttendingProviders: List["AvailableSlotsVisitAttendingProvider"] = Field(None)
    Locations: List["AvailableSlotsVisitLocation"] = Field(None)
    Reasons: List[str] = Field(None)


class AvailableSlotsVisitAttendingProvider(RedoxAbstractModel):

    Address: "AvailableSlotsVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AvailableSlotsVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "AvailableSlotsVisitAttendingProviderPhoneNumber" = Field(None)


class AvailableSlotsVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AvailableSlotsVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AvailableSlotsVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class AvailableSlotsVisitLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


AvailableSlots.update_forward_refs()
AvailableSlotsMeta.update_forward_refs()
AvailableSlotsPatient.update_forward_refs()
AvailableSlotsVisit.update_forward_refs()
AvailableSlotsVisitAttendingProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class ProviderQueryResponse(EventTypeAbstractModel):

    Meta: "ProviderQueryResponseMeta" = Field(...)
    Providers: List["ProviderQueryResponseProvider"] = Field(...)


class ProviderQueryResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["ProviderQueryResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["ProviderQueryResponseMetaLog"] = Field(None)
    Message: "ProviderQueryResponseMetaMessage" = Field(None)
    Source: "ProviderQueryResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "ProviderQueryResponseMetaTransmission" = Field(None)


class ProviderQueryResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ProviderQueryResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class ProviderQueryResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ProviderQueryResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ProviderQueryResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ProviderQueryResponseProvider(RedoxAbstractModel):

    Demographics: "ProviderQueryResponseProviderDemographics" = Field(None)
    Identifiers: List["ProviderQueryResponseProviderIdentifier"] = Field(...)
    IsActive: bool = Field(...)
    Qualifications: List["ProviderQueryResponseProviderQualification"] = Field(None)
    Roles: List["ProviderQueryResponseProviderRole"] = Field(None)


class ProviderQueryResponseProviderDemographics(RedoxAbstractModel):

    Addresses: List["ProviderQueryResponseProviderDemographicsAddress"] = Field(None)
    Credentials: List[str] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Languages: List[str] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "ProviderQueryResponseProviderDemographicsPhoneNumber" = Field(None)
    Sex: Union[str, None] = Field(None)


class ProviderQueryResponseProviderDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    Use: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ProviderQueryResponseProviderDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class ProviderQueryResponseProviderIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)


class ProviderQueryResponseProviderQualification(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Identifiers: List["ProviderQueryResponseProviderQualificationIdentifier"] = Field(
        None
    )
    StartDate: Union[str, None] = Field(None)


class ProviderQueryResponseProviderQualificationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRole(RedoxAbstractModel):

    Availability: List["ProviderQueryResponseProviderRoleAvailability"] = Field(None)
    Identifiers: List["ProviderQueryResponseProviderRoleIdentifier"] = Field(None)
    Locations: List["ProviderQueryResponseProviderRoleLocation"] = Field(None)
    Organization: "ProviderQueryResponseProviderRoleOrganization" = Field(None)
    Services: List["ProviderQueryResponseProviderRoleService"] = Field(None)
    Specialties: List["ProviderQueryResponseProviderRoleSpecialty"] = Field(None)


class ProviderQueryResponseProviderRoleAvailability(RedoxAbstractModel):

    AvailableEndTime: Union[str, None] = Field(None)
    AvailableStartTime: Union[str, None] = Field(None)
    Days: List[str] = Field(None)


class ProviderQueryResponseProviderRoleIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleLocation(RedoxAbstractModel):

    Address: "ProviderQueryResponseProviderRoleLocationAddress" = Field(None)
    Description: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Identifiers: List["ProviderQueryResponseProviderRoleLocationIdentifier"] = Field(
        None
    )
    Name: Union[str, None] = Field(None)
    PhoneNumber: "ProviderQueryResponseProviderRoleLocationPhoneNumber" = Field(None)
    Status: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleLocationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleLocationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleOrganization(RedoxAbstractModel):

    Address: "ProviderQueryResponseProviderRoleOrganizationAddress" = Field(None)
    Identifiers: List[
        "ProviderQueryResponseProviderRoleOrganizationIdentifier"
    ] = Field(None)
    IsActive: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleService(RedoxAbstractModel):

    Description: Union[str, None] = Field(None)
    Identifiers: List["ProviderQueryResponseProviderRoleServiceIdentifier"] = Field(
        None
    )
    PhoneNumber: "ProviderQueryResponseProviderRoleServicePhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleServiceIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleServicePhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ProviderQueryResponseProviderRoleSpecialty(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


ProviderQueryResponse.update_forward_refs()
ProviderQueryResponseMeta.update_forward_refs()
ProviderQueryResponseProvider.update_forward_refs()
ProviderQueryResponseProviderDemographics.update_forward_refs()
ProviderQueryResponseProviderQualification.update_forward_refs()
ProviderQueryResponseProviderRole.update_forward_refs()
ProviderQueryResponseProviderRoleLocation.update_forward_refs()
ProviderQueryResponseProviderRoleOrganization.update_forward_refs()
ProviderQueryResponseProviderRoleService.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Activate(EventTypeAbstractModel):

    Meta: "ActivateMeta" = Field(...)
    Providers: List["ActivateProvider"] = Field(...)


class ActivateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["ActivateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["ActivateMetaLog"] = Field(None)
    Message: "ActivateMetaMessage" = Field(None)
    Source: "ActivateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "ActivateMetaTransmission" = Field(None)


class ActivateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ActivateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class ActivateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ActivateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ActivateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ActivateProvider(RedoxAbstractModel):

    Demographics: "ActivateProviderDemographics" = Field(None)
    Identifiers: List["ActivateProviderIdentifier"] = Field(...)
    Qualifications: List["ActivateProviderQualification"] = Field(None)
    Roles: List["ActivateProviderRole"] = Field(None)


class ActivateProviderDemographics(RedoxAbstractModel):

    Addresses: List["ActivateProviderDemographicsAddress"] = Field(None)
    Credentials: List[str] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Languages: List[str] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "ActivateProviderDemographicsPhoneNumber" = Field(None)
    Sex: Union[str, None] = Field(None)


class ActivateProviderDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    Use: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ActivateProviderDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class ActivateProviderIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)


class ActivateProviderQualification(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Identifiers: List["ActivateProviderQualificationIdentifier"] = Field(None)
    StartDate: Union[str, None] = Field(None)


class ActivateProviderQualificationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ActivateProviderRole(RedoxAbstractModel):

    Availability: List["ActivateProviderRoleAvailability"] = Field(None)
    Identifiers: List["ActivateProviderRoleIdentifier"] = Field(None)
    Locations: List["ActivateProviderRoleLocation"] = Field(None)
    Organization: "ActivateProviderRoleOrganization" = Field(None)
    Services: List["ActivateProviderRoleService"] = Field(None)
    Specialties: List["ActivateProviderRoleSpecialty"] = Field(None)


class ActivateProviderRoleAvailability(RedoxAbstractModel):

    AvailableEndTime: Union[str, None] = Field(None)
    AvailableStartTime: Union[str, None] = Field(None)
    Days: List[str] = Field(None)


class ActivateProviderRoleIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ActivateProviderRoleLocation(RedoxAbstractModel):

    Address: "ActivateProviderRoleLocationAddress" = Field(None)
    Description: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Identifiers: List["ActivateProviderRoleLocationIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "ActivateProviderRoleLocationPhoneNumber" = Field(None)
    Status: Union[str, None] = Field(None)


class ActivateProviderRoleLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ActivateProviderRoleLocationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ActivateProviderRoleLocationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ActivateProviderRoleOrganization(RedoxAbstractModel):

    Address: "ActivateProviderRoleOrganizationAddress" = Field(None)
    Identifiers: List["ActivateProviderRoleOrganizationIdentifier"] = Field(None)
    IsActive: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class ActivateProviderRoleOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class ActivateProviderRoleOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ActivateProviderRoleService(RedoxAbstractModel):

    Description: Union[str, None] = Field(None)
    Identifiers: List["ActivateProviderRoleServiceIdentifier"] = Field(None)
    PhoneNumber: "ActivateProviderRoleServicePhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class ActivateProviderRoleServiceIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class ActivateProviderRoleServicePhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class ActivateProviderRoleSpecialty(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


Activate.update_forward_refs()
ActivateMeta.update_forward_refs()
ActivateProvider.update_forward_refs()
ActivateProviderDemographics.update_forward_refs()
ActivateProviderQualification.update_forward_refs()
ActivateProviderRole.update_forward_refs()
ActivateProviderRoleLocation.update_forward_refs()
ActivateProviderRoleOrganization.update_forward_refs()
ActivateProviderRoleService.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Update(EventTypeAbstractModel):

    Items: List["UpdateItem"] = Field(...)
    Meta: "UpdateMeta" = Field(...)


class UpdateItem(RedoxAbstractModel):

    ContainsLatex: Union[bool, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Identifiers: List["UpdateItemIdentifier"] = Field(...)
    IsChargeable: Union[bool, None] = Field(None)
    Location: "UpdateItemLocation" = Field(None)
    Notes: Union[str, None] = Field(None)
    Price: Union[Number, None] = Field(None)
    Procedure: "UpdateItemProcedure" = Field(None)
    Quantity: Union[Number, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)
    Vendor: "UpdateItemVendor" = Field(None)


class UpdateItemIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class UpdateItemLocation(RedoxAbstractModel):

    Bin: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class UpdateItemProcedure(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Modifier: Union[str, None] = Field(None)


class UpdateItemVendor(RedoxAbstractModel):

    CatalogNumber: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["UpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["UpdateMetaLog"] = Field(None)
    Message: "UpdateMetaMessage" = Field(None)
    Source: "UpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "UpdateMetaTransmission" = Field(None)


class UpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class UpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


Update.update_forward_refs()
UpdateItem.update_forward_refs()
UpdateMeta.update_forward_refs()
